@@ -6,7 +6,7 @@ T = TypeVar('T')
 
 @dataclass
 class DeckPartHolder(Generic[T]):
-    name: str
+    part_id: str
     save_to_file: Optional[str]
     deck_part: T
 
@@ -20,19 +20,19 @@ class DeckPartHolder(Generic[T]):
         return cls.file_manager
 
     @classmethod
-    def from_deck_part_pool(cls, name: str) -> T:
-        return cls.get_file_manager().deck_part_from_pool(name)
+    def from_deck_part_pool(cls, part_id: str) -> T:
+        return cls.get_file_manager().deck_part_from_pool(part_id)
 
     @classmethod
-    def override_or_create(cls, name: str, save_to_file: Optional[str], deck_part: T):
+    def override_or_create(cls, part_id: str, save_to_file: Optional[str], deck_part: T):
         fm = cls.get_file_manager()
 
-        dp = fm.deck_part_if_exists(name)
+        dp = fm.deck_part_if_exists(part_id)
         if dp is None:
-            dp = fm.new_deck_part(DeckPartHolder(name, save_to_file, deck_part))
+            dp = fm.new_deck_part(DeckPartHolder(part_id, save_to_file, deck_part))
         else:
             dp.deck_part = deck_part
-            dp.save_to_file = save_to_file  # ?
+            dp.save_to_file = save_to_file
 
         dp.write_to_file()
 
