@@ -18,8 +18,8 @@ def test_constructor(arg_reader_test1):
 
 class TestArguments:
     @pytest.mark.parametrize("arguments", [
-        (["test_builder.yaml", "--config"]),
-        (["test_builder.yaml", "config_file.yaml", "--config"]),
+        (["test_recipe.yaml", "--config"]),
+        (["test_recipe.yaml", "config_file.yaml", "--config"]),
         (["--config", "config_file.yaml"]),
         ([""]),
         ([])
@@ -32,16 +32,16 @@ class TestArguments:
             with patch.object(BBArgumentReader, "error", side_effect=raise_exit):
                 parsed_args = arg_reader_test1.get_parsed(arguments)
 
-    @pytest.mark.parametrize("arguments, builder_file, config_file, verify_only", [
-        (["test_builder.yaml"], "test_builder.yaml", None, False),
-        (["test_builder.yaml", "--verify"], "test_builder.yaml", None, True),
-        (["test_builder.yaml", "-v"], "test_builder.yaml", None, True),
-        (["test_builder.yaml", "--config", "other_config.yaml"], "test_builder.yaml", "other_config.yaml", False),
-        (["test_builder.yaml", "--config", "other_config.yaml", "-v"], "test_builder.yaml", "other_config.yaml", True),
+    @pytest.mark.parametrize("arguments, recipe, config_file, verify_only", [
+        (["test_recipe.yaml"], "test_recipe.yaml", None, False),
+        (["test_recipe.yaml", "--verify"], "test_recipe.yaml", None, True),
+        (["test_recipe.yaml", "-v"], "test_recipe.yaml", None, True),
+        (["test_recipe.yaml", "--config", "other_config.yaml"], "test_recipe.yaml", "other_config.yaml", False),
+        (["test_recipe.yaml", "--config", "other_config.yaml", "-v"], "test_recipe.yaml", "other_config.yaml", True),
     ])
-    def test_correct_arguments(self, arg_reader_test1, arguments, builder_file, config_file, verify_only):
+    def test_correct_arguments(self, arg_reader_test1, arguments, recipe, config_file, verify_only):
         parsed_args = arg_reader_test1.parse_args(arguments)
 
-        assert parsed_args.builder_file == builder_file
+        assert parsed_args.recipe == recipe
         assert parsed_args.config_file == config_file
         assert parsed_args.verify_only == verify_only
